==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/UebaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.UebaArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.UebaDataSources
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings with single toggle.
 * Azure REST API version: 2023-06-01-preview. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * ## Example Usage
 * ### Update EyesOn settings.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var ueba = new AzureNative.SecurityInsights.Ueba("ueba", new()
 *     {
 *         ResourceGroupName = "myRg",
 *         SettingsName = "EyesOn",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewUeba(ctx, "ueba", &securityinsights.UebaArgs{
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			SettingsName:      pulumi.String("EyesOn"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.Ueba;
 * import com.pulumi.azurenative.securityinsights.UebaArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var ueba = new Ueba("ueba", UebaArgs.builder()
 *             .resourceGroupName("myRg")
 *             .settingsName("EyesOn")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:Ueba EyesOn /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/settings/{settingsName}
 * ```
 * @property dataSources The relevant data sources that enriched by ueba
 * @property kind The kind of the setting
 * Expected value is 'Ueba'.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property settingsName The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
 * @property workspaceName The name of the workspace.
 */
public data class UebaArgs(
    public val dataSources: Output<List<Either<String, UebaDataSources>>>? = null,
    public val kind: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val settingsName: Output<String>? = null,
    public val workspaceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.UebaArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.UebaArgs =
        com.pulumi.azurenative.securityinsights.UebaArgs.builder()
            .dataSources(
                dataSources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .kind(kind?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .settingsName(settingsName?.applyValue({ args0 -> args0 }))
            .workspaceName(workspaceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UebaArgs].
 */
@PulumiTagMarker
public class UebaArgsBuilder internal constructor() {
    private var dataSources: Output<List<Either<String, UebaDataSources>>>? = null

    private var kind: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var settingsName: Output<String>? = null

    private var workspaceName: Output<String>? = null

    /**
     * @param value The relevant data sources that enriched by ueba
     */
    @JvmName("mykqcxviyneethkh")
    public suspend fun dataSources(`value`: Output<List<Either<String, UebaDataSources>>>) {
        this.dataSources = value
    }

    @JvmName("ogeucbbrfmvyxqea")
    public suspend fun dataSources(vararg values: Output<Either<String, UebaDataSources>>) {
        this.dataSources = Output.all(values.asList())
    }

    /**
     * @param values The relevant data sources that enriched by ueba
     */
    @JvmName("vxijytmavfctarrw")
    public suspend fun dataSources(values: List<Output<Either<String, UebaDataSources>>>) {
        this.dataSources = Output.all(values)
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'Ueba'.
     */
    @JvmName("tkslvockniaxhwxe")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gsjmhychivcorupq")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("myriuuhwiloihpgc")
    public suspend fun settingsName(`value`: Output<String>) {
        this.settingsName = value
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("tvjgquwkeiqumrdi")
    public suspend fun workspaceName(`value`: Output<String>) {
        this.workspaceName = value
    }

    /**
     * @param value The relevant data sources that enriched by ueba
     */
    @JvmName("gfcaaofjetwkhioy")
    public suspend fun dataSources(`value`: List<Either<String, UebaDataSources>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataSources = mapped
    }

    /**
     * @param values The relevant data sources that enriched by ueba
     */
    @JvmName("kijfyamuoyjatnck")
    public suspend fun dataSources(vararg values: Either<String, UebaDataSources>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataSources = mapped
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'Ueba'.
     */
    @JvmName("ivsovutwcauhqfno")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("eyjaepkhmrrfhfhm")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("wyoiksotyfyvdrmm")
    public suspend fun settingsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingsName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("xywlpgkjomlsxmkw")
    public suspend fun workspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceName = mapped
    }

    internal fun build(): UebaArgs = UebaArgs(
        dataSources = dataSources,
        kind = kind,
        resourceGroupName = resourceGroupName,
        settingsName = settingsName,
        workspaceName = workspaceName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/UebaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin

import com.pulumi.azurenative.securityinsights.UebaArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.UebaDataSources
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Settings with single toggle.
 * Azure REST API version: 2023-06-01-preview. Prior API version in Azure Native 1.x: 2021-03-01-preview.
 * ## Example Usage
 * ### Update EyesOn settings.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var ueba = new AzureNative.SecurityInsights.Ueba("ueba", new()
 *     {
 *         ResourceGroupName = "myRg",
 *         SettingsName = "EyesOn",
 *         WorkspaceName = "myWorkspace",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/securityinsights/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := securityinsights.NewUeba(ctx, "ueba", &securityinsights.UebaArgs{
 * 			ResourceGroupName: pulumi.String("myRg"),
 * 			SettingsName:      pulumi.String("EyesOn"),
 * 			WorkspaceName:     pulumi.String("myWorkspace"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.securityinsights.Ueba;
 * import com.pulumi.azurenative.securityinsights.UebaArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var ueba = new Ueba("ueba", UebaArgs.builder()
 *             .resourceGroupName("myRg")
 *             .settingsName("EyesOn")
 *             .workspaceName("myWorkspace")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:securityinsights:Ueba EyesOn /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/workspaces/{workspaceName}/providers/Microsoft.SecurityInsights/settings/{settingsName}
 * ```
 * @property dataSources The relevant data sources that enriched by ueba
 * @property kind The kind of the setting
 * Expected value is 'Ueba'.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property settingsName The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
 * @property workspaceName The name of the workspace.
 */
public data class UebaArgs(
    public val dataSources: Output<List<Either<String, UebaDataSources>>>? = null,
    public val kind: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val settingsName: Output<String>? = null,
    public val workspaceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.UebaArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.UebaArgs =
        com.pulumi.azurenative.securityinsights.UebaArgs.builder()
            .dataSources(
                dataSources?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .kind(kind?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .settingsName(settingsName?.applyValue({ args0 -> args0 }))
            .workspaceName(workspaceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UebaArgs].
 */
@PulumiTagMarker
public class UebaArgsBuilder internal constructor() {
    private var dataSources: Output<List<Either<String, UebaDataSources>>>? = null

    private var kind: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var settingsName: Output<String>? = null

    private var workspaceName: Output<String>? = null

    /**
     * @param value The relevant data sources that enriched by ueba
     */
    @JvmName("vajawkvwdeyuuugs")
    public suspend fun dataSources(`value`: Output<List<Either<String, UebaDataSources>>>) {
        this.dataSources = value
    }

    @JvmName("ujpbekrbemoixghj")
    public suspend fun dataSources(vararg values: Output<Either<String, UebaDataSources>>) {
        this.dataSources = Output.all(values.asList())
    }

    /**
     * @param values The relevant data sources that enriched by ueba
     */
    @JvmName("vixatiqwjtysbsns")
    public suspend fun dataSources(values: List<Output<Either<String, UebaDataSources>>>) {
        this.dataSources = Output.all(values)
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'Ueba'.
     */
    @JvmName("onwrtxikblimutbr")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("krqxecqrfuninkds")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("dgpvrtwvqptoojrw")
    public suspend fun settingsName(`value`: Output<String>) {
        this.settingsName = value
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("juhahyihgrwvspwm")
    public suspend fun workspaceName(`value`: Output<String>) {
        this.workspaceName = value
    }

    /**
     * @param value The relevant data sources that enriched by ueba
     */
    @JvmName("outimctukgotrtnd")
    public suspend fun dataSources(`value`: List<Either<String, UebaDataSources>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataSources = mapped
    }

    /**
     * @param values The relevant data sources that enriched by ueba
     */
    @JvmName("novryxyemdwuyuad")
    public suspend fun dataSources(vararg values: Either<String, UebaDataSources>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataSources = mapped
    }

    /**
     * @param value The kind of the setting
     * Expected value is 'Ueba'.
     */
    @JvmName("tuxjtnnnrcsnxlqf")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("letekdkqwiyuegrm")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The setting name. Supports - Anomalies, EyesOn, EntityAnalytics, Ueba
     */
    @JvmName("uotfnlkbcfhiebec")
    public suspend fun settingsName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingsName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("facwbgqqxykhtcbk")
    public suspend fun workspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceName = mapped
    }

    internal fun build(): UebaArgs = UebaArgs(
        dataSources = dataSources,
        kind = kind,
        resourceGroupName = resourceGroupName,
        settingsName = settingsName,
        workspaceName = workspaceName,
    )
}
